// Copyright (c) 2015 GeometryFactory (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org).
// You can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Hole_filling/do_not_use_DT3.h $
// $Id: do_not_use_DT3.h ee57fc2 %aI Sébastien Loriot
// SPDX-License-Identifier: GPL-3.0+
// 
//
// Author(s)     : Jane Tournois

#ifndef CGAL_POLYGON_MESH_PROCESSING_INTERNAL_HOLE_FILLING_DO_NOT_USE_DT3
#define CGAL_POLYGON_MESH_PROCESSING_INTERNAL_HOLE_FILLING_DO_NOT_USE_DT3

#include <CGAL/license/Polygon_mesh_processing/meshing_hole_filling.h>


#define CGAL_HOLE_FILLING_DO_NOT_USE_DT3

#endif // CGAL_POLYGON_MESH_PROCESSING_INTERNAL_HOLE_FILLING_DO_NOT_USE_DT3
